from question_builder.data.question_type_repository.verbs.future_continuous.FCC_question_getter import (
    FCCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.future_continuous.FCNC_question_getter import (
    FCNCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.future_perfect.FPC_question_getter import (
    FPCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.future_perfect.FPNC_question_getter import (
    FPNCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.future_perfect_continuous.FPCC_question_getter import (
    FPCCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.future_perfect_continuous.FPCNC_question_getter import (
    FPCNCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.going_to_future.FDV_question_getter import (
    FDVQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.going_to_future.GTFC_question_getter import (
    GTFCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.going_to_future.GTFNC_question_getter import (
    GTFNCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.irregular_past_tense.IRTCP_question_getter import (
    IRTCPQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.passive_voice.PVC_question_getter import (
    PVCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.past_continuous.PACC_question_getter import (
    PACCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.past_continuous.PACNC_question_getter import (
    PACNCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.past_perfect.PAPC_question_getter import (
    PAPCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.past_perfect.PAPNC_question_getter import (
    PAPNCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.past_perfect_continuous.PPCC_question_getter import (
    PPCCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.past_perfect_continuous.PPCNC_question_getter import (
    PPCNCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.present_continuous.PCC_question_getter import (
    PCCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.present_continuous.PCFT_question_getter import (
    PCFTQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.present_continuous.PCIPT_question_getter import (
    PCIPTQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.present_continuous.PCNC_question_getter import (
    PCNCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.present_continuous.PCNFT_question_getter import (
    PCNFTQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.present_continuous.PCNPT_question_getter import (
    PCNPTQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.present_continuous.PCPT_question_getter import (
    PCPTQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.present_perfect.PPC_question_getter import (
    PPCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.present_perfect.PPNC_question_getter import (
    PPNCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.present_perfect_continuous.PRPCC_question_getter import (
    PRPCCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.present_perfect_continuous.PRPCNC_question_getter import (
    PRPCNCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.simple_future.SFC2_question_getter import (
    SFC2QuestionGetter,
)
from question_builder.data.question_type_repository.verbs.simple_future.SFC_question_getter import (
    SFCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.simple_future.SFNC_question_getter import (
    SFNCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.simple_past.SPANC_question_getter import (
    SPANCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.simple_present.SPNC_question_getter import (
    SPNCQuestionGetter,
)
from question_builder.data.question_type_repository.verbs.simple_present.STC_question_getter import (
    STCQuestionGetter,
)
